@@ -246,7 +246,7 @@ const loadBoard = async () => {
const data = await getSuggestions()
suggestions.value = data.suggestions || []
- // Build ecology tag options from user's own topics
+ // Build board tag options from user's own topics
const allCoopTags = cooperativeTagOptions.value
const myTopicSlugs = (memberData.value?.board?.topics || []).map((t) => t.tagSlug)
boardTagOptions.value = myTopicSlugs.length
diff --git a/app/pages/members/[id].vue b/app/pages/members/[id].vue
index 6a76016..2f29438 100644
--- a/app/pages/members/[id].vue
+++ b/app/pages/members/[id].vue
@@ -508,7 +508,7 @@ useHead({
}
/* ====================================================
- TWO-COLUMN: Craft Tags + Community Ecology
+ TWO-COLUMN: Craft Tags + Board
==================================================== */
.profile-two-col {
diff --git a/server/api/events/recommended.get.js b/server/api/events/recommended.get.js
index 7036fd2..9c830f6 100644
--- a/server/api/events/recommended.get.js
+++ b/server/api/events/recommended.get.js
@@ -5,10 +5,10 @@ import { requireAuth } from '../../utils/auth.js'
export default defineEventHandler(async (event) => {
const member = await requireAuth(event)
- // Combine craft tags and cooperative ecology tags
+ // Combine craft tags and board topic tags
const craftTags = member.craftTags || []
- const ecologyTags = (member.board?.topics || []).map(t => t.tagSlug)
- const memberTags = [...new Set([...craftTags, ...ecologyTags].filter(Boolean))]
+ const boardTags = (member.board?.topics || []).map(t => t.tagSlug)
+ const memberTags = [...new Set([...craftTags, ...boardTags].filter(Boolean))]
if (!memberTags.length) {
return []
diff --git a/server/api/onboarding/status.get.js b/server/api/onboarding/status.get.js
index 5f3448c..33efffe 100644
--- a/server/api/onboarding/status.get.js
+++ b/server/api/onboarding/status.get.js
@@ -10,7 +10,7 @@ export default defineEventHandler(async (event) => {
const hasVisitedEvent = !!member.onboarding?.eventPageVisited
const topics = member.board?.topics || []
- const hasEngagedEcology =
+ const hasEngagedBoard =
!!member.onboarding?.boardPageVisited &&
topics.some((t) => ['help', 'interested', 'seeking'].includes(t.state))
@@ -20,7 +20,7 @@ export default defineEventHandler(async (event) => {
goals: {
hasProfileTags,
hasVisitedEvent,
- hasEngagedEcology,
+ hasEngagedBoard,
hasClickedWiki,
},
completedAt: member.onboarding?.completedAt || null,
diff --git a/server/api/wiki/recommended.get.js b/server/api/wiki/recommended.get.js
index fc37ad7..b251c0b 100644
--- a/server/api/wiki/recommended.get.js
+++ b/server/api/wiki/recommended.get.js
@@ -5,10 +5,10 @@ import { requireAuth } from '../../utils/auth.js'
export default defineEventHandler(async (event) => {
const member = await requireAuth(event)
- // Combine craft tags and cooperative ecology tags
+ // Combine craft tags and board topic tags
const craftTags = member.craftTags || []
- const ecologyTags = (member.board?.topics || []).map(t => t.tagSlug)
- const memberTags = [...new Set([...craftTags, ...ecologyTags].filter(Boolean))]
+ const boardTags = (member.board?.topics || []).map(t => t.tagSlug)
+ const memberTags = [...new Set([...craftTags, ...boardTags].filter(Boolean))]
if (!memberTags.length) {
return []
diff --git a/tests/server/api/onboarding-status.test.js b/tests/server/api/onboarding-status.test.js
index d725f8f..b989b83 100644
--- a/tests/server/api/onboarding-status.test.js
+++ b/tests/server/api/onboarding-status.test.js
@@ -38,7 +38,7 @@ describe('GET /api/onboarding/status', () => {
goals: {
hasProfileTags: false,
hasVisitedEvent: false,
- hasEngagedEcology: false,
+ hasEngagedBoard: false,
hasClickedWiki: false,
},
completedAt: null,
@@ -87,8 +87,8 @@ describe('GET /api/onboarding/status', () => {
expect(result.goals.hasProfileTags).toBe(false)
})
- // 1.5: hasEngagedEcology true when visited AND has tag with engagement state
- it('hasEngagedEcology is true when page visited and has engaged topic', async () => {
+ // 1.5: hasEngagedBoard true when visited AND has tag with engagement state
+ it('hasEngagedBoard is true when page visited and has engaged topic', async () => {
requireAuth.mockResolvedValue({
_id: 'member-1',
craftTags: [],
@@ -106,11 +106,11 @@ describe('GET /api/onboarding/status', () => {
const event = createMockEvent({ method: 'GET', path: '/api/onboarding/status' })
const result = await handler(event)
- expect(result.goals.hasEngagedEcology).toBe(true)
+ expect(result.goals.hasEngagedBoard).toBe(true)
})
- // 1.6: hasEngagedEcology false when visited but no engagement state
- it('hasEngagedEcology is false when page visited but no topics have engagement state', async () => {
+ // 1.6: hasEngagedBoard false when visited but no engagement state
+ it('hasEngagedBoard is false when page visited but no topics have engagement state', async () => {
requireAuth.mockResolvedValue({
_id: 'member-1',
craftTags: [],
@@ -126,7 +126,7 @@ describe('GET /api/onboarding/status', () => {
const event = createMockEvent({ method: 'GET', path: '/api/onboarding/status' })
const result = await handler(event)
- expect(result.goals.hasEngagedEcology).toBe(false)
+ expect(result.goals.hasEngagedBoard).toBe(false)
})
// 1.9: Maps stored booleans directly
@@ -147,7 +147,7 @@ describe('GET /api/onboarding/status', () => {
const result = await handler(event)
expect(result.goals.hasVisitedEvent).toBe(true)
- expect(result.goals.hasEngagedEcology).toBe(false)
+ expect(result.goals.hasEngagedBoard).toBe(false)
expect(result.goals.hasClickedWiki).toBe(true)
})